@@ -6,14 +6,14 @@ mod router;
 mod request;
 mod response;
 
+pub use crate::{get_param, get_query, get_body};
 pub use self::application::Application;
 pub use self::application::ServiceProvider;
 pub use self::application::Provider;
 pub use self::http_core::HttpCore;
 pub use self::http_core::HttpCoreHandler;
 pub use self::router::{RouterHandler, Router};
-pub use self::request::Request;
-pub use self::request::RequestBuilder;
+pub use self::request::{Request, RequestBuilder};
 pub use self::response::Response;
 pub use self::logger::Logger;
-pub use self::logger::Log;
+pub use self::logger::Log;
\ No newline at end of file
